Monty Python's Flying Circus: Just the Words - Episode 23

# Episode Twenty-three

French subtitled film
Scott of the Antarctic
Scott of the Sahara
Fish Licence
Derby Council v. All Blacks rugby match
Long John Silver Impersonators v. Bournemouth Gynaecologist

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Exterior large rubbish dump. Hand-held camera tracks to girl in simple white dress with red hair fourteen foot long, who is sitting on a chair holding a cabbage in her hands. After a time Stig, in white jeans, shirt and scarf enters shot and stands around uneasily.
Stig | Bonjour.
| SUBTITLE: 'GOOD MORNING'
Girl | Bonjour.
| SUBTITLE: 'GOOD MORNING'
| Pause. Stig looks uneasy, glancing at camera.
Stig | II fair beau ce matin.
| SUBTITLE: 'IT'S A NICE DAY'
Girl | Oui, oui.
| SUBTITLE: 'YES, YES'
Stig | D'accord...
| SUBTITLE: 'HEAR HEAR'
Stig | Venez-vous ici souvent?
| SUBTITLE: 'DO YOU COME HERE OFTEN?'
Girl | Oui.
| SUBTITLE: 'YES'
Stig | Ah. Bon. Bon.
| SUBTITLE: 'GOOD, GOOD'
| Pause.
Stig | Je vois que vous avez un chou.
| SUBTITLE: 'I SEE THAT YOU HAVE A CABBAGE'
Girl | Oui.
| SUBTITLE: 'YES'
| Stig starts to laugh falsely, and then the girl joins in. It is a miserable attempt to capture joy and togetherness. The girl stops laughing before Stig does.
Stig | Certainement il fair beau ce matin.
| SUBTITLE: 'IT CERTAINLY IS A LOVELY DAY ALL RIGHT'
| Stig wanders out of shot but is very obviously pushed back into the picture.
Stig | Je suis revolutionnaire.
| SUBTITLE: 'I AM A REVOLUTIONARY'
Girl | Oh.
Stig | Qu'est-ce que vous avez dit?
| SUBTITLE: 'WHAT DID YOU SAY?'
Girl | J'ai dit 'oh'.
| SUBTITLE: 'I SAID "OH"'
Stig | Ah. Très interessant.
| SUBTITLE: 'AH. VERY INTERESTING'
| Cut to pimply youth in studio.
Phil | Brian Distel and Brianette Zatapathique there in an improvised scene from Jean Kenneth Longueur's new movie 'Le Fromage Grand'. Brian and Brianette symbolize the breakdown in communication in our modern society in this exciting new film and Longueur is saying to us, his audience, 'go on, protest, do something about it, assault the manager, demand your money back'. Later on in the film, in a brilliantly conceived montage, Longueur mercilessly exposes the violence underlying our society when Brian and Brianerte again meet on yet another rubbish dump.
| Different part of same dump, but not very different. Girl is still on chair but this time with a head of lettuce. Then Stig enters shot.
Stig | Bonjour encore.
| SUBTITLE: 'HELLO AGAIN'
Girl | Bonjour.
| SUBTITLE: 'GOOD MORNING'
Stig | Je vois que aujourd'jui vous avez une co-laitue.
| SUBTITLE: 'I SEE YOU'VE GOT A WEBB'S WONDER TODAY'
Girl | Oui.
Stig | Bon.
| SUBTITLE: 'GOOD'
| Intercut quick shot from war film: machine-gunner in plane.
Stig | Il fair beau encore.
| SUBTITLE: 'IT'S A LOVELY DAY AGAIN'
| Shot of Paris riots and clubbing.
Girl | Oui.
| SUBTITLE: 'YES'
Stig | Bon.
| SUBTITLE: 'GOOD'
| Shot of Michael being struck on head with a club by John.
Stig | Vous pouvez dire ça encore.
| SUBTITLE: 'IT CERTAINLY IS A LOVELY DAY ALL RIGHT'
| Shot of collapsing building, then a man at a piano (Graham); the lid slams on his hands.
Stig | Certainement il fair beau ce matin.
| SUBTITLE: 'IT CERTAINLY IS A LOVELY DAY ALL RIGHT'
| Shot of aeroplanes bombing. Shot of chef receiving arrow in chest. Shot of girl kicking tall man on shin. Shot of rockets being fired from plane.
Girl | Oui.
| SUBTITLE: 'YES'
| Shot of hydrogen bomb.
Stig | Il fait beau bier. Ha ha ha.
| SUBTITLE: 'IT WAS LOVELY YESTERDAY. HA HA HA'
| Shot of ack ack gun. Shot of man receiving a punch in the head from a boxing glove. Shot of nun kicking a policeman in the crutch.
Girl | Ha ha.
| SUBTITLE: 'HA HA. HA HA. HA HA.'
| Shot of Spitfire. Shot of Korean soldier; then man being beheaded.
Stig | Quel surprise de vous voir encore.
| SUBTITLE: 'WHAT A SURPRISE TO SEE YOU AGAIN'
| Shot of Paris riots. Shot of man having his foot stamped on. Shot of blazing building. Shot of man being poked in the eye with an umbrella. Shot of battleship firing broadside. Shot of man in underpants having a bucket of water thrown over him. Shot of soccer violence. Shot of man bring knifed by a Greek Orthodox priest.
Girl | Je t'aime.
| SUBTITLE: 'I LOVE YOU'
Stig | Je t'aime.
| SUBTITLE: 'I LOVE YOU'
| They smile at each other happily for a moment. Then they hear something ticking. They listen carefully for a moment and then both start to look fearfully at the cos lettuce. After a moment of terror the cos lettuce explodes, in slow motion, blowing them apart. As tatters and pieces of cos lettuce float through the air in slow motion, the camera pans down to some autumn leaves. Freeze frame.
| SUPERIMPOSED CAPTION: 'FIN'
| Cut back to Phil.
Phil | Pretty strong meat there from Longueur who is saying, of course, that ultimately materialism, in this case the Webb's Wonder lettuce, must destroy us all. That was for O. Simon, K. Simon, P. Simon and R. Sparrow of Leicester. Later on, we're going to take a look at John Wayne's latest movie, 'Buckets of Blood Pouring Out of People's Heads' but now we look ahead. On Tuesday Chris Conger took a BBC film unit to the location where 20th Century Vole are shooting their latest epic 'Scott of the Antarctic'.
| Chris Conger standing with back to pier and a few holidaymakers behind him.
Conger | Sea, sand and sunshine make Paignton the queen of the English Riviera. But for the next six months this sleepy Devonshire resort will be transformed into the blizzard-swept wastes of the South Pole. For today shooting starts on the epic 'Scott of the Antarctic', produced by Gerry Schlick. (walks over to Schlick)
Schlick | (American) Hello.
Conger | Gerry, you chose Paignton as the location for Scott.
Schlick | Right, right.
Conger | Isn't it a bit of a drawback that there's no snow here?
Schlick | Well, we have 28,000 cubic feet of Wintrex, which is a new white foam rubber which actually on screen looks more like snow than snow...
| Cut to shot of people nailing and sticking white foam rubber over things. It looks terrible. Others are painting the sand with white paint.
Schlick | ... and 1,600 cubic US furlongs of white paint, with a special snow finish.
Conger | And I believe Kirk Vilb is playing the title role.
Schlick | That is correct. We were very thrilled and honoured when Kirk agreed to play the part of Lieutenant Scott (cut to Kirk Vilb who is wearing fur open at the chest; he is having a chest wig stuck on and icing sugar squeezed on to his nose and eyebrows) because a star of his magnitude can pick and choose, but he read the title and just flipped. (cut back to Gerry Schlick and Chris Conger) And directing we have a very fine young British director, James McRettin, who's been collaborating on the screenplay, of course Jimmy...
| McRettin rushes into foreground. He is in no way like J. McGrath.
McRettin | Oh, there you are. Hello. Hello. No problem. Have a drink. Have a drink. Great. Hello. Marvellous. Marvellous. Hello. Rewrite. Oh this is really great. I mean, it's really saying something, don't you think?
Conger | Have you started shooting yet?
McRettin | Yes, yes. Great. Perfect. No, no, we haven't started yet. No. But great - great.
Conger | What is the first scene that you shoot this morning?
McRettin | Great. Terrific. Oh it's great. No problem. We'll sort it out on the floor. Sort it out on the floor. No problem. This film is basically pro-humanity and anti-bad things and it rips aside the hypocritical facade of our society's gin and tonic and leaves a lot of sacred cows rolling around in agony, have a drink, have a drink.
Conger | But which scene are we shooting first, Jimmy?
McRettin | Yes, great. Oh, marvellous. (calls out) Which scene are we shooting first? What? (to Conger) It's scene one. Scene one. It's in the middle of the movie. Well, it is now. I rewrote it. (calls.) I thought we cut that? Didn't we cut that?
Schlick | No, we didn't.
McRettin | We didn't. Oh great. That's even better. I'll put it back in. Rewrite. (calling) Scene one's back in everyone. Scene one's back in. Great. Great. (to Conger) This is the scene - outside the tent - it's all bloody marvelous. It makes you want to throw up.
| Cut to Schlick and Conger on the beach.
Schlick | Now in this scene Lieutenant Scott returns to camp in the early morning after walking the huskies to have brunch with the rest of his team. (cut to shot of tent with Bowers, who is black, and Oates, sitting outside) Oates, played by your very own lovely Terence Lemming, who is an English cockney officer seconded to the US Navy, and Bowers played by Seymour Fortescue, the Olympic pole vaulter.
| Film: Scott comes up to them. He has two large boxes strapped to his feet to make him look tall.
Oates | Hi, Lieutenant.
Scott | Hi, Oatesy. Sure is a beautiful day already.
McRettin | (rushing in) Great, great.
Scott | What? What are you saying?
McRettin | I was just saying great, great. Cue Evans.
| Sexy girl with long blond hair comes into shot with short pink fur coat. She walks up to Scott who towers four feet above her as she is walking in a trench.
Schlick | And this is Vanilla Hoare as Miss Evans.
Conger | Miss Evans?
Schlick | Right.
| Miss Evans is now beneath Scott at knee height.
Scott | Good morning, Miss Evans.
Evans | Oh, I've forgotten my line.
McRettin | What's her line? What's her line?
| Girl runs in with script.
Girl | It's 'Good morning, Captain Scott'.
Evans | Oh, yeah. 'Good morning, Captain Sc'..; oh, I'm just not really very happy with that line. Could I just say 'Hi Scottie'?
McRettin | Great. Great. Rewrite. Cue.
Evans | Hi Scarrie! Oh, sorry. Hi Stocky! Oh - I'm sorry again. Oh, Jim. I'm just unhappy with this line. Hey, can I do it all sort of kooky, like this? (goes beserk waving hands) Hi Scottie!
McRettin | Great! We'll shoot it.
Scott | Are you sure that's right?
McRettin | Oh, it's great.
| Gerry Schlick walks into the shot.
Schlick | Jim.
McRettin | Jim! Jim! Oh, me!
Schlick | Jim, I feel we may be running into some problems here in the area of height.
McRettin | Great! Where are they?
Schlick | Where are who?
McRettin | I don't know. I was getting confused.
Schlick | Jim, I feel here, that Scott may be too tall in the area of height with reference to Vanilla who is too near the ground in the area of being too short at this time.
McRettin | Great ... Oh, I know. I'm going to dig a pit for Scott and put a box in Vanilla's trench.
Scott | Say, why don't I take the boxes off and Vanilla get up out of the trench?
McRettin | It wouldn't work... It's even better! Great. Rewrite!
Evans | What was that?
McRettin | Oh, it's easy. I've worked it out. Scott takes his boxes off and you don't stand in the trench.
Evans | I say my lines out of the trench?
McRettin | Even better. Great.
Evans | But I've never acted out of a trench. I might fall over. It's dangerous.
McRettin | Oh well, could you just try it?
Evans | Look, you crumb bum, I'm a star. Star, star, star. I don't get a million dollars to act out of a trench. I played Miss St John the Baptist in a trench, (she walks along in the trench and we see that she has two boxes strapped to her feet) and I played Miss Napoleon Bonaparte in a trench, and I played Miss Alexander Fleming in a furrow so if you want this scene played out of a trench, well you just get yourself a goddamn stuntman. (walks off) I played Miss Galileo in a groove and I played Mrs Jesus Christ in a geological syncline, so don't...
McRettin | Great. Great everyone. Lunch now. Lunch. It's all in the can. Good morning's work.
Schlick | But you haven't done a shot.
McRettin | Just keeping morale up. (tries to take a drink from his view finder)
| The same afternoon.
Schlick | Now this afternoon we're going to shoot the scene where Scott gets off the boat on to the ice floe and he sees the lion and he fights it and kills it and the blood goes pssssssssshhh in slow motion.
Conger | But there aren't any lions in the Antarctic.
Schlick | What?
Conger | There aren't any lions in the Antarctic.
Schlick | You're right. There are no lions in the Antarctic. That's ridiculous! Whoever heard of a lion in the Antarctic? Right. Lose the lion.
McRettin | Got to keep the lion. It's great!
Schlick | Lose the lion.
McRettin | Great. We're losing the lion. Rewrite. Lose the lion everyone. That's fantastic.
Scott | What's this about our losing the lion?
Schlick | Well, Kirk, we thought perhaps we might lose the fight with the lion a little bit, Kirk, angel.
Scott | (loudly) Why?
Schlick | Well, Kirkie, doll, there are no lions in the Antarctic, baby.
Scott | (shouts) I get to fight the lion.
Schlick | It'd be silly.
Scott | Listen, I gotta fight the lion. That's what that guy Scott's all about. I know. I've studied him already.
Schlick | But why couldn't you fight a penguin?
McRettin | Great! (falls over)
Scott | Fight a rotten penguin?
Schlick | It needn't be a little penguin. It can be the biggest penguin you've ever seen. An electric penguin, twenty feet high, with long green tentacles that sting people, and you can stab it in the wings and the blood can go spurting psssssshhhh in slow motion.
Scott | The lion is in the contract.
Schlick | He fights the lion.
McRettin | Even better. Great. Have a drink. Lose the penguin. Stand by to shoot. (falls over)
Schlick | Where do they have lions?
Conger | Africa.
Schlick | That's it. Scott's in Africa. As many lions as we need.
McRettin | Great!
Schlick | He's looking for a pole no one else knows about. That ties in with the sand. Right. Paint the sand yellow again. Okay, let's get this show on the road. 'Scott of the Sahara.'
| Cut instantly to sky.
| CAPTION: 'SCOTT OF THE SAHARA'
Voice Over | Booming out of the pages of history comes a story of three men and one woman whose courage shocked a generation.
| Blinding sun. Pan down to Paignton beach. Scott, Evans, Oates and Bowers wearing furs crossing sand on snow shoes. With sledge pulled by motley selection of mongrel dogs, badly disguised as huskies.
Voice Over | From the same team that brought you ... (the names come out superimposed) 'Lawrence of Glareorgan' ... 'Bridge Over the River Trent' ... 'The Mad Woman of Biggleswade' ... and 'Krakatoa, East of Leamington' ... comes the story of three people and a woman united by fate who set out in search of the fabled Pole of the Sahara and found ... themselves. See ... Lieutenant Scott's death struggle with a crazed desert lion.
| The four are walking along. Suddenly they stop, stare, and react in horror. Scott steps to the front to defend the others. Intercut, non-matching stock shot of lion running out of jungle and leaping at camera. Scott waits poised and is then struck by completely rigid stuffed lion. Montage of shots of him wrestling, firstly with the stuffed lion, then with an actor in a tatty lion suit. The lion picks up a chair, fends Scott off, smashes it over his head. Finally Scott kicks the lion on the shin. The lion leaps around on one leg and picks up a knife. Scott points, the lion looks, Scott kicks the knife out of the lion's paw. He advances on the lion, and socks him on the jaw. The lion collapses in slow motion. After a pause, phoney blood spurts out.
Voice Over | See Ensign Oates' frank adult death struggle with the spine-chilling giant electric penguin...
| Oates looks up in horror, a shadow crosses him. Reverse shot of model penguin (quite small, about a foot) which lights up and looks electric. The penguin is close to the camera in the foreground and appears huge. Oates looks around desperately then starts to undress. Shot of penguin throwing tentacle. Half-nude Oates struggles with it. Intercut a lot of phoney reverses. Oates by now clad only in posing briefs sees a stone. He picks up the stone, then camera zooms into above-naval shot; he removes his briefs, puts the stone in the briefs, twirls it like a sling, and releases stone. The penguin is hit on beak, and falls over backwards.
Voice Over | ... See Miss Evans pursued by the man-eating roll-top writing desk.
| Miss Evans is running along screaming. Shot of desk chasing her (phoney desk with man inside). The roll top goes up and down, emitting roars, and displaying fearsome white teeth inside. As Evans runs, her clothing gets torn on each of the three cactuses. These are well spaced apart so that there is a lot of trouble to get near them. When she is practically nude, she runs out of shot revealing the announcer.
Announcer | And now for something completely different.
It's Man | It's...
| ANIMATION: dancing teeth. Then animation of a letter being resealed and posted - all backwards - ending in a real post office. A post office worker removes the stamp from the letter and hands it to man.
Post Office Worker | Five pence please.
| The man walks out backwards, pasing Mr Praline as he enters. He looks at the man, puzzled, and then goes up to first of two grils which has a sign saying 'stamps and licences'.
Praline | Excuse me, I would like to buy a fish license, please. (the man behind the counter points to next grille; to camera) The man's sign must be wrong. I have in the past noticed a marked discrepancy between these post office signs and the activities carried on beneath. But soft, let us see how Dame Fortune smiles upon my next postal adventure! (he goes to next grille) Hello, I would like to buy a fish licence, please.
Man | A what?
Praline | A license for my pet fish, Eric.
Man | How did you know my name was Eric?
Praline | No no no, my fish's name is Eric, Eric the fish. 'E's an 'alibut.
Man | A what?
Praline | He is an halibut.
Man | You've got a pet halibut?
Praline | Yes. I chose him out of thousands. I didn't like the others, they were all too flat.
Man | You must be a loony.
Praline | I am not a looney! Why should I be tied with the epithet looney merely because I have a pet halibut? I've heard tell that Sir Gerald Nabardo has a pet prawn called Simon and you wouldn't call him a looney; furthermore, Dawn Pailthorpe, the lady show-jumper, had a clam, called Stafford, after the late Chancellor, Allan Bullock has two pikes, both called Chris, and Marcel Proust had an haddock! So, if you're calling the author of 'A la recherche du temps perdu' a looney, I shall have to ask you to step outside!
Man | All right, all right, all right. You want a licence.
Praline | Yes.
Man | For a fish.
Praline | Yes.
Man | You are a loony.
Praline | Look, it's a bleeding pet, isn't it? I've got a license for me pet dog Eric, and I've got a license for me pet cat Eric...
Man | You don't need a license for a cat.
Praline | I bleeding well do and I got one. Ho, ho, you're not catching me out there.
Man | There's no such thing as a bloody cat license.
Praline | Yes there is!
Man | No there isn't!
Praline | Is!
Man | Isn't!
Praline | Is!
Man | Isn't!
Praline | Is!
Man | Isn't!
Praline | Is!
Man | Isn't!
Praline | Is!
Man | Isn't!
Praline | Is!
Man | Isn't!
Praline | What's that then?
Man | This is a dog license with the word 'dog' crossed out and the word 'cat' written in in crayon.
Praline | The man didn't have the proper form.
Man | What man?
Praline | The man from the cat detector van.
Man | Loony detector van, you mean.
Praline | It's people like you what cause unrest.
Man | All right, what cat detector van?
Praline | The cat detector van from the Ministry of Housinge.
Man | Housinge?
Praline | It was spelt like that on the van. I'm very observant!. I never seen so many bleeding aerials. The man said that their equipment could pinpoint a purr at four hundred yards...and Eric, being such a happy cat, was a piece of cake.
Man | How much did you pay for this?
Praline | Sixty quid, and eight guineas for the fruit bat.
Man | What fruit bat?
Praline | Eric the fruit-bat.
Man | Are all your pets called Eric?
Praline | There's nothing so odd about that: Kemal Ataturk had an entire menagerie, all called Abdul!
Man | No he didn't!
Praline | (takes book from pocket) He did, he did, he did, he did and did. There you are. 'Kemal Ataturk, the Man' by E. W. Swanton with a foreword by Paul Anka, page 91, please.
Man | (referring to page 91) I owe you an apology, sir.
Praline | Spoken like a gentleman, sir. Now, are you going to give me a fish license?
Man | I promise you that there is no such thing. You don't need one.
Praline | Then I would like a statement to that effect signed by the Lord Mayor.
| Fanfare of trumpets. Mayor gorgeously dressed with dignitaries enters flanked by trumpeters.
Man | You're in luck.
| In long shot now. The Mayor, who is nine foot high, and dignitaries approach a startled Praline. Organ music below a reverent voice over:
Voice Over | And now, there is the Mayor. Surely the third tallest mayor in Derby's history. And there are the Aldermen magnificently resplendent in their Aldermanic hose and just look at the power in those thighs. The New Zealanders are going to find it pretty tough going in the set pieces in the second half... So Dawn Palethorpe with one clear round on Sir Gerald... and now the Mayor has reached the Great Customer Mr Eric Praline. (the mayor takes a piece of Paper from the post office man) And now the Mayoral human being takes the Mayoral Pen in the Mayoral hand and watched by the Lady Mayoress, who of course scored that magnificent try in the first half, signs the fishy exemption (the mayor signs it and hands it to Praline) and the Great Customer, Mr Eric Praline, who is understandably awed by the magnificence and even the absurdity of this great occasion here at Cardiff Arms Park, (Praline looks very confused) has finally gone spare and there is the going sparal look on the front of his head. And now the Aldermen are finishing their oranges and leaving the post office for the start of the second half.
| They all exit out of door, eating oranges, and Praline looks after them. Cut to a rugby field. Crowd roaring as the aldermen, mayor, mayoress, town clerk, Dawn Palethorpe (on a horse) and the borough surveyor run onto the pitch and take up their positions.
Commentator | And here come the Derby Council XV following the All Blacks out on to the pitch. There, in the centre of the picture you can see Dawn Palethorpe on Sir Gerald - one of the fastest wingers we must have seen in England this season. On the left hand side of the picture the Lord Mayor has been running such wonderful possession for Derby Council in the lines out and it's the All Blacks to kick off. Wilson to kick off. Oh, I can see there the Chairman of the By-ways and Highways Committee who's obviously recovered from that very nasty blow he got in that loose ball in the first half. (opposite them the All Blacks kick off) And Wilson kicks off and it's the Town Clerk's taken the ball beautifully there, the All Blacks are up on it very fast and the whistle has gone. I'm not quite sure what happened there, I couldn't see, but there's a scrum-down. I think it's an All Blacks' ball. They were upon them very fast. Obviously they're going to try very hard in this half to wipe out this five-point deficit. Derby Council eight points to three up and Derby Council have got the ball against the head. There is the Borough Surveyor, the scrum-half is out of the ... er, the Chairman of the Highway and By-way Committee who's kicked for touch. The line out - and it's into the line out and the Mayor has got the ball again. To the Borough Surveyor who's left out the Medical Officer of Health. Straight along the line to the Lady Mayoress and the Lady Mayoress has got to go through. Number two has missed her - he's taken to the full back - only the full back to beat and she has scored! The Lady Mayoress has scored, it's eleven points to three.
| CAPTION: 'NEW ZEALAND 3 DERBY COUNCIL 11' Cut to linkman and Cliff Morgan.
Linkman | Cliff, this must have been a very disappointing result for the All Blacks.
Cliff | (Welsh) Well, they've had very bad luck on the tour so far. They missed four very easy kicks against the Exeter Amateur Operatic Society, which must have cost them the match and then of course there was that crippling defeat at the hands of the Derry and Toms Soft Toy Department, so I don't think they can be really fancying their chances against the London Pooves on Saturday.
Linkman | And what about China?
Cliff | Well, whether Mao Tse Tung is alive or not, Lin Piao has a stranglehold on the central committee which Lin Shao Chi can't break, so it remains to be seen whether Chou En Lai can really get his finger out and get going in the second half.
Linkman | Well, thank you Cliff. Tonight's other outstanding match was the semi-final between the Bournemouth Gynaecologists and the Watford Long John Silver Impersonators. We bring you edited highlights of the match.
| Rapid montage of goals scored by competent gynaecologists wearing surgical gowns and caps, against totally incompetent and immobile LJSI team who simply stand round going 'aaah! Jim lad' as the goals rain in. The ball is tucked off-screen. Sudden cut to studio. A presenter is standing in front of curtain; he catches the ball thrown from off. He smiles.
Presenter | Well, that's about it for tonight ladies and gentlemen, but remember if you've enjoyed watching the show just half as much as we've enjoyed doing it, then we've enjoyed it twice as much as you. Ha, ha, ha.
| The sixteen-ton weight falls on him. Cut to montage of scenes of destruction, buildings falling down, bombs etc. Roll credits over.